@@ -10,7 +10,7 @@ use Mojo::IOLoop::Server;
 use Mojo::IOLoop::Stream;
 use Mojo::Reactor::Poll;
 use Mojo::Util 'md5_sum';
-use Scalar::Util qw(blessed weaken);
+use Scalar::Util 'weaken';
 use Time::HiRes 'time';
 
 use constant DEBUG => $ENV{MOJO_IOLOOP_DEBUG} || 0;
@@ -32,6 +32,28 @@ $SIG{PIPE} = 'IGNORE';
 # Initialize singleton reactor early
 __PACKAGE__->singleton->reactor;
 
+sub acceptor {
+  my ($self, $acceptor) = @_;
+  $self = $self->singleton unless ref $self;
+
+  # Find acceptor for id
+  return $self->{acceptors}{$acceptor} unless ref $acceptor;
+
+  # Make sure connection manager is running
+  $self->_manager;
+
+  # New acceptor
+  my $id = $self->_id;
+  $self->{acceptors}{$id} = $acceptor;
+  weaken $acceptor->reactor($self->reactor)->{reactor};
+  $self->{accepts} = $self->max_accepts if $self->max_accepts;
+
+  # Stop accepting
+  $self->_not_accepting;
+
+  return $id;
+}
+
 sub client {
   my ($self, $cb) = (shift, pop);
   $self = $self->singleton unless ref $self;
@@ -113,15 +135,8 @@ sub server {
   my ($self, $cb) = (shift, pop);
   $self = $self->singleton unless ref $self;
 
-  # Make sure connection manager is running
-  $self->_manager;
-
   # New server
-  my $id = $self->_id;
-  my $server = $self->{servers}{$id} = Mojo::IOLoop::Server->new;
-  weaken $server->reactor($self->reactor)->{reactor};
-
-  # Listen
+  my $server = Mojo::IOLoop::Server->new;
   weaken $self;
   $server->on(
     accept => sub {
@@ -141,12 +156,8 @@ sub server {
     }
   );
   $server->listen(@_);
-  $self->{accepts} = $self->max_accepts if $self->max_accepts;
 
-  # Stop accepting
-  $self->_not_accepting;
-
-  return $id;
+  return $self->acceptor($server);
 }
 
 sub singleton { state $loop ||= shift->SUPER::new }
@@ -167,7 +178,7 @@ sub stream {
   $self = $self->singleton unless ref $self;
 
   # Connect stream with reactor
-  return $self->_stream($stream, $self->_id) if blessed $stream;
+  return $self->_stream($stream, $self->_id) if ref $stream;
 
   # Find stream for id
   return undef unless my $c = $self->{connections}{$stream};
@@ -186,8 +197,8 @@ sub _accepting {
 
   # Check connection limit
   return if $self->{accepting};
-  my $servers = $self->{servers} ||= {};
-  return unless keys %$servers;
+  my $acceptors = $self->{acceptors} ||= {};
+  return unless keys %$acceptors;
   my $i   = keys %{$self->{connections}};
   my $max = $self->max_connections;
   return unless $i < $max;
@@ -197,7 +208,7 @@ sub _accepting {
 
   # Check if multi-accept is desirable and start accepting
   my $multi = $self->multi_accept;
-  $_->multi_accept($max < $multi ? 1 : $multi)->start for values %$servers;
+  $_->multi_accept($max < $multi ? 1 : $multi)->start for values %$acceptors;
   $self->{accepting}++;
 }
 
@@ -205,7 +216,7 @@ sub _id {
   my $self = shift;
   my $id;
   do { $id = md5_sum('c' . time . rand 999) }
-    while $self->{connections}{$id} || $self->{servers}{$id};
+    while $self->{connections}{$id} || $self->{acceptors}{$id};
   return $id;
 }
 
@@ -224,7 +235,7 @@ sub _manage {
 
   # Graceful stop
   $self->_remove(delete $self->{manager})
-    unless keys %$connections || keys %{$self->{servers}};
+    unless keys %$connections || keys %{$self->{acceptors}};
   $self->stop if $self->max_connections == 0 && keys %$connections == 0;
 }
 
@@ -242,7 +253,7 @@ sub _not_accepting {
   $self->$cb();
 
   # Stop accepting
-  $_->stop for values %{$self->{servers} || {}};
+  $_->stop for values %{$self->{acceptors} || {}};
 }
 
 sub _remove {
@@ -252,8 +263,8 @@ sub _remove {
   return unless my $reactor = $self->reactor;
   return if $reactor->remove($id);
 
-  # Listen socket
-  if (delete $self->{servers}{$id}) { delete $self->{accepting} }
+  # Acceptor
+  if (delete $self->{acceptors}{$id}) { delete $self->{accepting} }
 
   # Connection (stream needs to be deleted first)
   else {
@@ -434,6 +445,14 @@ processes. Note that exceptions in this callback are not captured.
 L<Mojo::IOLoop> inherits all methods from L<Mojo::Base> and implements the
 following new ones.
 
+=head2 C<acceptor>
+
+  my $server = Mojo::IOLoop->acceptor($id);
+  my $server = $loop->acceptor($id);
+  my $id     = $loop->acceptor(Mojo::IOLoop::Server->new);
+
+Get L<Mojo::IOLoop::Server> object for id or turn object into an acceptor.
+
 =head2 C<client>
 
   my $id
@@ -588,7 +607,7 @@ event loop can be restarted by running C<start> again.
 
   my $stream = Mojo::IOLoop->stream($id);
   my $stream = $loop->stream($id);
-  my $id     = $loop->stream($stream);
+  my $id     = $loop->stream(Mojo::IOLoop::Stream->new);
 
 Get L<Mojo::IOLoop::Stream> object for id or turn object into a connection.
 
