@@ -156,6 +156,9 @@ Mojo::IOLoop::Client - Non-blocking TCP client
   });
   $client->connect(address => 'mojolicio.us', port => 80);
 
+  # Start reactor if necessary
+  $client->reactor->start unless $client->reactor->is_running;
+
 =head1 DESCRIPTION
 
 L<Mojo::IOLoop::Client> opens TCP connections for L<Mojo::IOLoop>.
