@@ -89,7 +89,8 @@ sub listen {
       '!aNULL:!eNULL:!EXPORT:!DSS:!DES:!SSLv2:!LOW:RC4-SHA:RC4-MD5:ALL',
     SSL_honor_cipher_order => 1,
     SSL_key_file           => $args->{tls_key} || $KEY,
-    SSL_startHandshake     => 0
+    SSL_startHandshake     => 0,
+    SSL_verify_mode        => 0x00
   };
   return unless $args->{tls_ca};
   $options->{SSL_ca_file} = -T $args->{tls_ca} ? $args->{tls_ca} : undef;
