@@ -20,7 +20,7 @@ sub DESTROY {
   my $self = shift;
   return unless my $loop = $self->ioloop;
   $self->_remove($_) for keys %{$self->{connections} || {}};
-  $loop->remove($_) for @{$self->{listening} || []};
+  $loop->remove($_) for @{$self->{acceptors} || []};
 }
 
 sub run {
@@ -55,8 +55,32 @@ sub setuidgid {
 
 sub start {
   my $self = shift;
-  $self->_listen($_) for @{$self->listen};
-  $self->ioloop->max_connections($self->max_clients);
+
+  # Resume accepting connections
+  my $loop = $self->ioloop;
+  if (my $acceptors = $self->{acceptors}) {
+    push @$acceptors, $loop->acceptor(delete $self->{servers}{$_})
+      for keys %{$self->{servers}};
+  }
+
+  # Start listening
+  else { $self->_listen($_) for @{$self->listen} }
+  $loop->max_connections($self->max_clients);
+
+  return $self;
+}
+
+sub stop {
+  my $self = shift;
+
+  # Pause accepting connections
+  my $loop = $self->ioloop;
+  while (my $id = shift @{$self->{acceptors}}) {
+    my $server = $self->{servers}{$id} = $loop->acceptor($id);
+    $loop->remove($id);
+    $server->stop;
+  }
+
   return $self;
 }
 
@@ -192,7 +216,7 @@ sub _listen {
           sub { $self->app->log->debug('Inactivity timeout.') if $c->{tx} });
     }
   );
-  push @{$self->{listening} ||= []}, $id;
+  push @{$self->{acceptors} ||= []}, $id;
 
   # Friendly message
   return if $self->silent;
@@ -436,6 +460,12 @@ Set user and group for process.
 
 Start accepting connections.
 
+=head2 C<stop>
+
+  $daemon = $daemon->stop;
+
+Stop accepting connections.
+
 =head1 DEBUGGING
 
 You can set the C<MOJO_DAEMON_DEBUG> environment variable to get some advanced
