@@ -198,19 +198,21 @@ implements the following new ones.
 
   $tx->client_close;
 
-Transaction closed client-side.
+Transaction closed client-side, used to implement user agents.
 
 =head2 C<client_read>
 
   $tx->client_read($chunk);
 
-Read data client-side. Meant to be overloaded in a subclass.
+Read data client-side, used to implement user agents. Meant to be overloaded
+in a subclass.
 
 =head2 C<client_write>
 
   my $chunk = $tx->client_write;
 
-Write data client-side. Meant to be overloaded in a subclass.
+Write data client-side, used to implement user agents. Meant to be overloaded
+in a subclass.
 
 =head2 C<connection>
 
@@ -261,19 +263,21 @@ Remote interface address.
 
   $tx->server_close;
 
-Transaction closed server-side.
+Transaction closed server-side, used to implement web servers.
 
 =head2 C<server_read>
 
   $tx->server_read($chunk);
 
-Read data server-side. Meant to be overloaded in a subclass.
+Read data server-side, used to implement web servers. Meant to be overloaded
+in a subclass.
 
 =head2 C<server_write>
 
   my $chunk = $tx->server_write;
 
-Write data server-side. Meant to be overloaded in a subclass.
+Write data server-side, used to implement web servers. Meant to be overloaded
+in a subclass.
 
 =head2 C<success>
 
